"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const application_1 = require("@jupyterlab/application");
const apputils_1 = require("@jupyterlab/apputils");
const coreutils_1 = require("@jupyterlab/coreutils");
const docmanager_1 = require("@jupyterlab/docmanager");
const filebrowser_1 = require("@jupyterlab/filebrowser");
const contents_1 = require("./contents");
const browser_1 = require("./browser");
require("../style/index.css");
/**
 * GitHub filebrowser plugin state namespace.
 */
const NAMESPACE = 'github-filebrowser';
/**
 * The ID for the plugin.
 */
const PLUGIN_ID = '@jupyterlab/github:drive';
/**
 * The JupyterLab plugin for the GitHub Filebrowser.
 */
const fileBrowserPlugin = {
    id: PLUGIN_ID,
    requires: [
        docmanager_1.IDocumentManager,
        filebrowser_1.IFileBrowserFactory,
        application_1.ILayoutRestorer,
        coreutils_1.ISettingRegistry
    ],
    activate: activateFileBrowser,
    autoStart: true
};
/**
 * Activate the file browser.
 */
function activateFileBrowser(app, manager, factory, restorer, settingRegistry) {
    // Add the GitHub backend to the contents manager.
    const drive = new contents_1.GitHubDrive(app.docRegistry);
    manager.services.contents.addDrive(drive);
    // Create the embedded filebrowser. GitHub repos likely
    // don't need as often of a refresh interval as normal ones,
    // and rate-limiting can be an issue, so we give a 5 minute
    // refresh interval.
    const browser = factory.createFileBrowser(NAMESPACE, {
        driveName: drive.name,
        refreshInterval: 300000
    });
    const gitHubBrowser = new browser_1.GitHubFileBrowser(browser, drive);
    gitHubBrowser.title.iconClass = 'jp-GitHub-icon jp-SideBar-tabIcon';
    gitHubBrowser.title.caption = 'Browse GitHub';
    gitHubBrowser.id = 'github-file-browser';
    // Add the file browser widget to the application restorer.
    restorer.add(gitHubBrowser, NAMESPACE);
    app.shell.add(gitHubBrowser, 'left', { rank: 102 });
    let shouldWarn = false;
    const onSettingsUpdated = (settings) => __awaiter(this, void 0, void 0, function* () {
        const baseUrl = settings.get('baseUrl').composite;
        const accessToken = settings.get('accessToken').composite;
        drive.baseUrl = baseUrl || contents_1.DEFAULT_GITHUB_BASE_URL;
        if (accessToken) {
            let proceed = true;
            if (shouldWarn) {
                proceed = yield Private.showWarning();
            }
            if (!proceed) {
                settings.remove('accessToken');
            }
            else {
                drive.accessToken = accessToken;
            }
        }
        else {
            drive.accessToken = null;
        }
    });
    // Fetch the initial state of the settings.
    Promise.all([settingRegistry.load(PLUGIN_ID), app.restored])
        .then(([settings]) => {
        settings.changed.connect(onSettingsUpdated);
        onSettingsUpdated(settings);
        // Don't warn about access token on initial page load, but do for every setting thereafter.
        shouldWarn = true;
        const defaultRepo = settings.get('defaultRepo').composite;
        if (defaultRepo) {
            browser.model.restored.then(() => {
                browser.model.cd(`/${defaultRepo}`);
            });
        }
    })
        .catch((reason) => {
        console.error(reason.message);
    });
    return;
}
exports.default = fileBrowserPlugin;
/**
 * A namespace for module-private functions.
 */
var Private;
(function (Private) {
    /**
     * Show a warning dialog about security.
     *
     * @returns whether the user accepted the dialog.
     */
    function showWarning() {
        return __awaiter(this, void 0, void 0, function* () {
            return apputils_1.showDialog({
                title: 'Security Alert!',
                body: 'Adding a client side access token can pose a security risk! ' +
                    'Please consider using the server extension instead.' +
                    'Do you want to continue?',
                buttons: [
                    apputils_1.Dialog.cancelButton({ label: 'CANCEL' }),
                    apputils_1.Dialog.warnButton({ label: 'PROCEED' })
                ]
            }).then(result => {
                if (result.button.accept) {
                    return true;
                }
                else {
                    return false;
                }
            });
        });
    }
    Private.showWarning = showWarning;
})(Private || (Private = {}));
